package betterquesting.client.gui2.editors.nbt;

import betterquesting.api.client.gui.misc.IVolatileScreen;
import betterquesting.api.misc.ICallback;
import betterquesting.api2.client.gui.GuiScreenCanvas;
import betterquesting.api2.client.gui.controls.IPanelButton;
import betterquesting.api2.client.gui.controls.IValueIO;
import betterquesting.api2.client.gui.controls.PanelButton;
import betterquesting.api2.client.gui.events.IPEventListener;
import betterquesting.api2.client.gui.events.PEventBroadcaster;
import betterquesting.api2.client.gui.events.PanelEvent;
import betterquesting.api2.client.gui.events.types.PEventButton;
import betterquesting.api2.client.gui.misc.GuiAlign;
import betterquesting.api2.client.gui.misc.GuiPadding;
import betterquesting.api2.client.gui.misc.GuiTransform;
import betterquesting.api2.client.gui.misc.IGuiRect;
import betterquesting.api2.client.gui.panels.CanvasTextured;
import betterquesting.api2.client.gui.panels.bars.PanelVScrollBar;
import betterquesting.api2.client.gui.panels.content.PanelLine;
import betterquesting.api2.client.gui.panels.content.PanelTextBox;
import betterquesting.api2.client.gui.themes.presets.PresetColor;
import betterquesting.api2.client.gui.themes.presets.PresetLine;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import betterquesting.api2.utils.QuestTranslation;
import net.minecraft.client.gui.GuiScreen;
import net.minecraft.nbt.NBTBase;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;

/* loaded from: betterquesting_client_gui2_editors_nbt.jar:betterquesting/client/gui2/editors/nbt/GuiNbtEditor.class */
public class GuiNbtEditor extends GuiScreenCanvas implements IPEventListener, IVolatileScreen {
    private final NBTBase nbt;
    private final ICallback<NBTTagCompound> comCallback;
    private final ICallback<NBTTagList> lstCallback;

    public GuiNbtEditor(GuiScreen parent, NBTTagCompound tag, ICallback<NBTTagCompound> callback) {
        super(parent);
        this.nbt = tag;
        this.comCallback = callback;
        this.lstCallback = null;
    }

    public GuiNbtEditor(GuiScreen parent, NBTTagList tag, ICallback<NBTTagList> callback) {
        super(parent);
        this.nbt = tag;
        this.comCallback = null;
        this.lstCallback = callback;
    }

    public void initPanel() {
        PanelScrollingNBT pnEdit;
        super.initPanel();
        PEventBroadcaster.INSTANCE.register(this, PEventButton.class);
        CanvasTextured cvBackground = new CanvasTextured(new GuiTransform(GuiAlign.FULL_BOX, new GuiPadding(0, 0, 0, 0), 0), PresetTexture.PANEL_MAIN.getTexture());
        addPanel(cvBackground);
        cvBackground.addPanel(new PanelButton(new GuiTransform(GuiAlign.BOTTOM_CENTER, -100, -16, 200, 16, 0), 0, QuestTranslation.translate("gui.back", new Object[0])));
        PanelTextBox txTitle = new PanelTextBox(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 16, 0, -32), 0), QuestTranslation.translate(this.nbt.func_74732_a() == 9 ? "betterquesting.title.json_array" : "betterquesting.title.json_object", new Object[0])).setAlignment(1);
        txTitle.setColor(PresetColor.TEXT_HEADER.getColor());
        cvBackground.addPanel(txTitle);
        if (this.nbt.func_74732_a() == 10) {
            pnEdit = new PanelScrollingNBT((IGuiRect) new GuiTransform(GuiAlign.FULL_BOX, new GuiPadding(16, 32, 24, 32), 0), this.nbt, 1, 2, 3, 4);
        } else {
            pnEdit = new PanelScrollingNBT((IGuiRect) new GuiTransform(GuiAlign.FULL_BOX, new GuiPadding(16, 32, 24, 32), 0), this.nbt, 1, 2, 3, 4);
        }
        cvBackground.addPanel(pnEdit);
        IValueIO panelVScrollBar = new PanelVScrollBar(new GuiTransform(GuiAlign.RIGHT_EDGE, new GuiPadding(-24, 32, 16, 32), 0));
        cvBackground.addPanel(panelVScrollBar);
        pnEdit.setScrollDriverY(panelVScrollBar);
        GuiTransform guiTransform = new GuiTransform(GuiAlign.TOP_LEFT, 16, 32, 0, 0, 0);
        guiTransform.setParent(cvBackground.getTransform());
        GuiTransform guiTransform2 = new GuiTransform(GuiAlign.TOP_RIGHT, -16, 32, 0, 0, 0);
        guiTransform2.setParent(cvBackground.getTransform());
        PanelLine paLine0 = new PanelLine(guiTransform, guiTransform2, PresetLine.GUI_DIVIDER.getLine(), 1, PresetColor.GUI_DIVIDER.getColor(), -1);
        cvBackground.addPanel(paLine0);
        GuiTransform guiTransform3 = new GuiTransform(GuiAlign.BOTTOM_LEFT, 16, -32, 0, 0, 0);
        guiTransform3.setParent(cvBackground.getTransform());
        GuiTransform guiTransform4 = new GuiTransform(GuiAlign.BOTTOM_RIGHT, -16, -32, 0, 0, 0);
        guiTransform4.setParent(cvBackground.getTransform());
        PanelLine paLine1 = new PanelLine(guiTransform3, guiTransform4, PresetLine.GUI_DIVIDER.getLine(), 1, PresetColor.GUI_DIVIDER.getColor(), -1);
        cvBackground.addPanel(paLine1);
    }

    public void onPanelEvent(PanelEvent event) {
        if (event instanceof PEventButton) {
            onButtonPress((PEventButton) event);
        }
    }

    private void onButtonPress(PEventButton event) {
        IPanelButton btn = event.getButton();
        if (btn.getButtonID() == 0) {
            this.field_146297_k.func_147108_a(this.parent);
            if (this.nbt.func_74732_a() == 10 && this.comCallback != null) {
                this.comCallback.setValue(this.nbt);
            } else if (this.nbt.func_74732_a() == 9 && this.lstCallback != null) {
                this.lstCallback.setValue(this.nbt);
            }
        }
    }
}
